summaryrefslogtreecommitdiff
path: root/src/lib/exchange_api_reserve.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2019-11-23 22:21:47 +0100
committerChristian Grothoff <christian@grothoff.org>2019-11-23 22:21:47 +0100
commit7aae6c90452c1e9bcae78a5e948f381c1165010a (patch)
treee4520eafe637260b87fabe9f272abd275a3b91d7 /src/lib/exchange_api_reserve.c
parent51e54bbaa18397f599e5078153671c98c719c695 (diff)
downloadexchange-7aae6c90452c1e9bcae78a5e948f381c1165010a.tar.gz
exchange-7aae6c90452c1e9bcae78a5e948f381c1165010a.tar.bz2
exchange-7aae6c90452c1e9bcae78a5e948f381c1165010a.zip
use CONFLICT for double spending to distinguish properly from FORBIDDEN for bad signatures
Diffstat (limited to 'src/lib/exchange_api_reserve.c')
-rw-r--r--src/lib/exchange_api_reserve.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/exchange_api_reserve.c b/src/lib/exchange_api_reserve.c
index a57d4e9dc..2c62cac20 100644
--- a/src/lib/exchange_api_reserve.c
+++ b/src/lib/exchange_api_reserve.c
@@ -797,7 +797,7 @@ reserve_withdraw_ok (struct TALER_EXCHANGE_ReserveWithdrawHandle *wsh,
/**
* We got a 403 FORBIDDEN response for the /reserve/withdraw operation.
* Check the signatures on the withdraw transactions in the provided
* history and that the balances add up. We don't do anything directly
* with the information, as the JSON will be returned to the application.
@@ -941,7 +941,7 @@ handle_reserve_withdraw_finished (void *cls,
/* This should never happen, either us or the exchange is buggy
(or API version conflict); just pass JSON reply to the application */
break;
- case MHD_HTTP_FORBIDDEN:
+ case MHD_HTTP_CONFLICT:
/* The exchange says that the reserve has insufficient funds;
check the signatures in the history... */
if (GNUNET_OK !=
@@ -952,7 +952,7 @@ handle_reserve_withdraw_finished (void *cls,
response_code = 0;
}
break;
- case MHD_HTTP_UNAUTHORIZED:
+ case MHD_HTTP_FORBIDDEN:
GNUNET_break (0);
/* Nothing really to verify, exchange says one of the signatures is
invalid; as we checked them, this should never happen, we
@@ -797,7 +797,7 @@ reserve_withdraw_ok (struct TALER_EXCHANGE_ReserveWithdrawHandle *wsh,
/**
- * We got a 403 FORBIDDEN response for the /reserve/withdraw operation.
+ * We got a 409 CONFLICT response for the /reserve/withdraw operation.
* Check the signatures on the withdraw transactions in the provided
* history and that the balances add up. We don't do anything directly